@@ -1,12 +1,22 @@
 package Moo::Role;
 
 use Moo::_strictures;
-use Moo::_Utils;
+use Moo::_Utils qw(
+  _getglob
+  _getstash
+  _install_coderef
+  _install_modifier
+  _load_module
+  _name_coderef
+  _set_loaded
+  _unimport_coderefs
+);
 use Sub::Defer ();
 use Role::Tiny ();
+use Carp qw(croak);
 our @ISA = qw(Role::Tiny);
 
-our $VERSION = '2.001000';
+our $VERSION = '2.001001';
 $VERSION = eval $VERSION;
 
 require Moo::sification;
@@ -48,8 +58,7 @@ sub import {
     my $name_proto = shift;
     my @name_proto = ref $name_proto eq 'ARRAY' ? @$name_proto : $name_proto;
     if (@_ % 2 != 0) {
-      require Carp;
-      Carp::croak("Invalid options for " . join(', ', map "'$_'", @name_proto)
+      croak("Invalid options for " . join(', ', map "'$_'", @name_proto)
         . " attribute(s): even number of arguments expected, got " . scalar @_)
     }
     my %spec = @_;
